'use strict';

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var util = require('lodash-provider');

/**
 * Turn the given value into an array.  If it is already an array then return it; if it is a set then convert to an
 * array; and if neither then return as the first item in an array. The purpose of this function is for function
 * or method parameters where they can be either a array or not.  You can use this to ensure you are working on
 * an array.
 *
 * @public
 * @param {Array|Set|*} value		Value to return or convert.
 * @returns {Array}					The converted value (or original if already an array).
 */
util.makeArray = function makeArray(value) {
  if (value === undefined) return [];
  if (value instanceof Set) return [].concat(_toConsumableArray(value));
  return util.castArray(value);
};

/**
 * Take a path and lop one level off it
 *
 * @param {string} path		Path to lop.
 * @returns {string}		new path.
 */
util.lopped = function lopped(path) {
  var parts = path.split('/');
  parts.pop();
  return parts;
};

/**
 * Insert function text into source code at given comment.
 *
 * @param {string} txt					Text to insert into..
 * @param {string} insertPoint			Text to insert at.
 * @param {Array.<Function>} ...funcs	Functions to get source of and insert.
 * @returns {string}					New text.
 */
util.insertFunctions = function insertFunctions(txt, insertPoint) {
  for (var _len = arguments.length, funcs = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    funcs[_key - 2] = arguments[_key];
  }

  return txt.replace(insertPoint, funcs.map(function (functionName) {
    return (functionName || '').toString();
  }).filter(function (funcName) {
    return funcName !== '';
  }).join(''));
};

module.exports = util;